==> htmlunit-2.26-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/event/EventSource.java <==
/*
 * Copyright (c) 2002-2017 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.event;

import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.CHROME;
import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.FF;

import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstant;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;
import com.gargoylesoftware.htmlunit.javascript.configuration.WebBrowser;

/**
 * A JavaScript object for {@code EventSource}.
 *
 * @author Ahmed Ashour
 */
@JsxClass(browsers = {@WebBrowser(CHROME), @WebBrowser(FF)})
public class EventSource extends EventTarget {

    /** The connection is being established. */
    @JsxConstant
    public static final short CONNECTING = 0;

    /** The connection is open and dispatching events. */
    @JsxConstant
    public static final short OPEN = 1;

    /** The connection is not being established, has been closed or there was a fatal error. */
    @JsxConstant
    public static final short CLOSED = 2;

    /**
     * Default constructor.
     */
    @JsxConstructor
    public EventSource() {
    }
}

==> htmlunit-2.29-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/event/EventSource.java <==
/*
 * Copyright (c) 2002-2017 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.event;

import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.CHROME;
import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.FF;

import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstant;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;

/**
 * A JavaScript object for {@code EventSource}.
 *
 * @author Ahmed Ashour
 */
@JsxClass({CHROME, FF})
public class EventSource extends EventTarget {

    /** The connection is being established. */
    @JsxConstant
    public static final short CONNECTING = 0;

    /** The connection is open and dispatching events. */
    @JsxConstant
    public static final short OPEN = 1;

    /** The connection is not being established, has been closed or there was a fatal error. */
    @JsxConstant
    public static final short CLOSED = 2;

    /**
     * Default constructor.
     */
    @JsxConstructor
    public EventSource() {
    }
}
